summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/kstarssplash.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/kstarssplash.cpp')
-rw-r--r--kstars/kstars/kstarssplash.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kstars/kstars/kstarssplash.cpp b/kstars/kstars/kstarssplash.cpp
index defd0007..ade62236 100644
--- a/kstars/kstars/kstarssplash.cpp
+++ b/kstars/kstars/kstarssplash.cpp
@@ -71,7 +71,7 @@ KStarsSplash::KStarsSplash( TQWidget *parent, const char* name )
topLayout->activate();
disableResize();
- setMessage(TQString()); // force tqrepaint of widget with no text
+ setMessage(TQString()); // force repaint of widget with no text
}
KStarsSplash::~KStarsSplash() {
@@ -80,8 +80,8 @@ KStarsSplash::~KStarsSplash() {
void KStarsSplash::paintEvent( TQPaintEvent* ) {
bitBlt( Banner, 0, 0, splashImage, 0, 0, -1, -1 );
- label->tqrepaint(); // standard text label
- textCurrentStatus->tqrepaint(); // status text label
+ label->repaint(); // standard text label
+ textCurrentStatus->repaint(); // status text label
}
void KStarsSplash::closeEvent( TQCloseEvent *e ) {
@@ -91,10 +91,10 @@ void KStarsSplash::closeEvent( TQCloseEvent *e ) {
void KStarsSplash::setMessage( TQString s ) {
textCurrentStatus->setText( s );
- tqrepaint(); // tqrepaint splash screen
+ repaint(); // repaint splash screen
/**
*Flush all event data. This is needed because events will buffered and
*tqrepaint call will queued in event buffer. With flush all X11 events of
*this application will flushed.
*/
kapp->flush();
@@ -91,10 +91,10 @@ void KStarsSplash::closeEvent( TQCloseEvent *e ) {
/**
*Flush all event data. This is needed because events will buffered and
- *tqrepaint call will queued in event buffer. With flush all X11 events of
+ *repaint call will queued in event buffer. With flush all X11 events of
*this application will flushed.
*/